"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackgroundMaskOptionsEditor = void 0;
const EditorBase_1 = require("../../../EditorBase");
const object_gui_1 = require("object-gui");
class BackgroundMaskOptionsEditor extends EditorBase_1.EditorBase {
    constructor(particles) {
        super(particles);
    }
    addToGroup(parent) {
        this.group = parent.addGroup("backgroundMask", "Background Mask");
        this.options = this.group.data;
        this.addCover();
        this.addProperties();
    }
    addCover() {
        const options = this.options().cover;
        const coverColor = options.color;
        const coverGroup = this.group.addGroup("cover", "Cover");
        coverGroup
            .addProperty("color", "Color", object_gui_1.EditorType.color, coverColor.value, false)
            .change(async (value) => {
            if (typeof value === "string") {
                coverColor.value = value;
            }
            await this.particles().refresh();
        });
        coverGroup
            .addProperty("opacity", "Opacity", object_gui_1.EditorType.number)
            .change(async () => {
            await this.particles().refresh();
        })
            .step(0.01)
            .min(0)
            .max(1);
    }
    addProperties() {
        this.group
            .addProperty("composite", "Composite", object_gui_1.EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems([
            {
                value: "source-over",
            },
            {
                value: "source-in",
            },
            {
                value: "source-out",
            },
            {
                value: "source-atop",
            },
            {
                value: "destination-over",
            },
            {
                value: "destination-in",
            },
            {
                value: "destination-out",
            },
            {
                value: "destination-atop",
            },
            {
                value: "lighter",
            },
            {
                value: "copy",
            },
            {
                value: "xor",
            },
            {
                value: "multiply",
            },
            {
                value: "screen",
            },
            {
                value: "overlay",
            },
            {
                value: "darken",
            },
            {
                value: "lighten",
            },
            {
                value: "color-dodge",
            },
            {
                value: "color-burn",
            },
            {
                value: "hard-light",
            },
            {
                value: "soft-light",
            },
            {
                value: "difference",
            },
            {
                value: "exclusion",
            },
            {
                value: "hue",
            },
            {
                value: "saturation",
            },
            {
                value: "color",
            },
            {
                value: "luminosity",
            },
        ]);
        this.group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
    }
}
exports.BackgroundMaskOptionsEditor = BackgroundMaskOptionsEditor;
