"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InfectionOptionsEditor = void 0;
const EditorBase_1 = require("../../../EditorBase");
const object_gui_1 = require("object-gui");
class InfectionOptionsEditor extends EditorBase_1.EditorBase {
    constructor(particles) {
        super(particles);
    }
    addToGroup(parent) {
        this.group = parent.addGroup("infection", "Infection");
        this.options = this.group.data;
        this.addStages();
        this.addProperties();
    }
    addProperties() {
        this.group.addProperty("cure", "Cure", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("delay", "Delay", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("infections", "Infections", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
    addStage(parent, stages, index) {
        const stageGroup = parent.addGroup(index().toString(10), `Stage ${index}`, true, stages);
        const stage = stageGroup.data;
        stageGroup
            .addProperty("color", "Color", object_gui_1.EditorType.color, stage().color, false)
            .change(async (value) => {
            if (typeof value === "string") {
                if (typeof stage().color === "string") {
                    stage().color = value;
                }
                else {
                    stage().color = {
                        value,
                    };
                }
            }
            await this.particles().refresh();
        });
        stageGroup.addProperty("duration", "Duration", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        stageGroup.addProperty("infectedStage", "Infected Stage", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        stageGroup.addProperty("radius", "Radius", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        stageGroup.addProperty("rate", "Rate", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
    addStages() {
        const options = this.options();
        const stagesGroup = this.group.addGroup("stages", "Stages");
        if (options && !options.stages) {
            options.stages = [];
        }
        if (options) {
            for (let i = 0; i < options.stages.length; i++) {
                this.addStage(stagesGroup, () => options.stages, () => i + 1);
            }
        }
        stagesGroup.addButton("addStage", "Add Stage", false).click(async () => {
            this.addStage(stagesGroup, () => this.options().stages, () => this.options().stages.length);
            await this.particles().refresh();
        });
    }
}
exports.InfectionOptionsEditor = InfectionOptionsEditor;
