"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinksOptionsEditor = void 0;
const EditorBase_1 = require("../../../../EditorBase");
const object_gui_1 = require("object-gui");
class LinksOptionsEditor extends EditorBase_1.EditorBase {
    constructor(particles) {
        super(particles);
    }
    addToGroup(parent) {
        this.group = parent.addGroup("links", "Links");
        this.options = this.group.data;
        this.addShadow();
        this.addTriangles();
        this.addProperties();
    }
    addProperties() {
        const optionsFunc = () => this.options();
        const options = optionsFunc();
        const color = typeof options.color === "string" ? options.color : options.color?.value;
        this.group.addProperty("blink", "Blink", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("color", "Color", object_gui_1.EditorType.color, color, false).change(async (value) => {
            const options = optionsFunc();
            if (typeof value === "string") {
                if (typeof options.color === "string") {
                    options.color = value;
                }
                else {
                    options.color.value = value;
                }
                await this.particles().refresh();
            }
        });
        this.group.addProperty("consent", "Consent", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("distance", "Distance", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        this.group
            .addProperty("frequency", "Frequency", object_gui_1.EditorType.number)
            .min(0)
            .max(1)
            .step(0.01)
            .change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("id", "Id", object_gui_1.EditorType.string).change(async () => {
            await this.particles().refresh();
        });
        this.group
            .addProperty("opacity", "Opacity", object_gui_1.EditorType.number)
            .change(async () => {
            await this.particles().refresh();
        })
            .step(0.01)
            .min(0)
            .max(1);
        this.group.addProperty("warp", "Warp", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        this.group.addProperty("width", "Width", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
    addShadow() {
        const group = this.group.addGroup("shadow", "Shadow");
        const optionsFunc = group.data;
        const options = optionsFunc();
        const color = typeof options.color === "string" ? options.color : options.color?.value;
        group.addProperty("blur", "Blur", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("color", "Color", object_gui_1.EditorType.color, color, false).change(async (value) => {
            const options = optionsFunc();
            if (typeof value === "string") {
                if (typeof options.color === "string") {
                    options.color = value;
                }
                else {
                    if (options.color === undefined) {
                        options.color = {
                            value: value,
                        };
                    }
                    else {
                        options.color.value = value;
                    }
                }
            }
            await this.particles().refresh();
        });
        group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
    }
    addTriangles() {
        const group = this.group.addGroup("triangles", "Triangles");
        const optionsFunc = () => this.options().triangles;
        const options = optionsFunc();
        const color = typeof options?.color === "string" ? options.color : options?.color?.value;
        group.addProperty("color", "Color", object_gui_1.EditorType.color, color, false).change(async (value) => {
            const options = optionsFunc();
            if (typeof value === "string") {
                if (typeof options.color === "string") {
                    options.color = value;
                }
                else {
                    if (options.color === undefined) {
                        options.color = {
                            value: value,
                        };
                    }
                    else {
                        options.color.value = value;
                    }
                }
            }
            await this.particles().refresh();
        });
        group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group
            .addProperty("frequency", "Frequency", object_gui_1.EditorType.number)
            .min(0)
            .max(1)
            .step(0.01)
            .change(async () => {
            await this.particles().refresh();
        });
        group
            .addProperty("opacity", "Opacity", object_gui_1.EditorType.number)
            .change(async () => {
            await this.particles().refresh();
        })
            .step(0.01)
            .min(0)
            .max(1);
    }
}
exports.LinksOptionsEditor = LinksOptionsEditor;
