"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpacityOptionsEditor = void 0;
const EditorBase_1 = require("../../../../EditorBase");
const object_gui_1 = require("object-gui");
class OpacityOptionsEditor extends EditorBase_1.EditorBase {
    constructor(particles) {
        super(particles);
    }
    addToGroup(parent, options) {
        this.group = parent.addGroup("opacity", "Opacity", true, options);
        this.options = this.group.data;
        this.addAnimation();
        this.addRandom();
        this.addProperties();
    }
    addAnimation() {
        const group = this.group.addGroup("animation", "Animation");
        group
            .addProperty("destroy", "Destroy", object_gui_1.EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems([
            {
                value: "max",
            },
            {
                value: "min",
            },
            {
                value: "none",
            },
        ]);
        group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group
            .addProperty("minimumValue", "Minimum Value", object_gui_1.EditorType.number)
            .change(async () => {
            await this.particles().refresh();
        })
            .min(0)
            .max(0)
            .step(0.01);
        group
            .addProperty("speed", "Speed", object_gui_1.EditorType.number)
            .change(async () => {
            await this.particles().refresh();
        })
            .step(0.01);
        group
            .addProperty("startValue", "Start Value", object_gui_1.EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems([
            {
                value: "max",
            },
            {
                value: "min",
            },
            {
                value: "random",
            },
        ]);
        group.addProperty("sync", "Sync", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
    }
    addProperties() {
        this.group
            .addProperty("value", "Value", object_gui_1.EditorType.number)
            .change(async () => {
            await this.particles().refresh();
        })
            .min(0)
            .max(1)
            .step(0.01);
    }
    addRandom() {
        const group = this.group.addGroup("random", "Random");
        group.addProperty("enable", "Enable", object_gui_1.EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("minimumValue", "Minimum Value", object_gui_1.EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
}
exports.OpacityOptionsEditor = OpacityOptionsEditor;
