import { EditorBase } from "../../../../EditorBase";
import { EditorType } from "object-gui";
export class MoveOptionsEditor extends EditorBase {
    constructor(particles) {
        super(particles);
    }
    addToGroup(parent) {
        this.group = parent.addGroup("move", "Move");
        this.options = this.group.data;
        this.addAngle();
        this.addAttract();
        this.addDistance();
        this.addGravity();
        this.addOutModes();
        this.addPath();
        this.addTrail();
        this.addProperties();
    }
    addAngle() {
        const group = this.group.addGroup("angle", "Angle");
        group.addProperty("offset", "Offset", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("value", "Value", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
    addAttract() {
        const group = this.group.addGroup("attract", "Attract");
        const rotateGroup = group.addGroup("rotate", "Rotate", false);
        rotateGroup.addProperty("x", "X", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        rotateGroup.addProperty("y", "Y", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("enable", "Enable", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
    }
    addDistance() {
        const group = this.group.addGroup("distance", "Distance");
        group.addProperty("horizontal", "Horizontal", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("vertical", "Vertical", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
    addGravity() {
        const group = this.group.addGroup("gravity", "Gravity");
        group.addProperty("acceleration", "Acceleration", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("enable", "Enable", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("maxSpeed", "Max Speed", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
    addOutModes() {
        const group = this.group.addGroup("outModes", "Out Modes");
        const outModesValues = [
            {
                value: "bounce",
            },
            {
                value: "destroy",
            },
            {
                value: "none",
            },
            {
                value: "split",
            },
            {
                value: "out",
            },
        ];
        group
            .addProperty("bottom", "Bottom", EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems(outModesValues);
        group
            .addProperty("default", "Default", EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems(outModesValues);
        group
            .addProperty("left", "Left", EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems(outModesValues);
        group
            .addProperty("right", "Right", EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems(outModesValues);
        group
            .addProperty("top", "Top", EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems(outModesValues);
    }
    addPath() {
        const group = this.group.addGroup("path", "Path");
        const delayGroup = group.addGroup("delay", "Delay");
        delayGroup.addProperty("value", "value", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        const randomGroup = delayGroup.addGroup("random", "Random");
        randomGroup.addProperty("enable", "Enable", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        randomGroup.addProperty("minimumValue", "Minimum Value", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("clamp", "Clamp", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("enable", "Enable", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("generator", "Generator", EditorType.string).change(async () => {
            await this.particles().refresh();
        });
    }
    addProperties() {
        const group = this.group;
        group
            .addProperty("direction", "Direction", EditorType.select)
            .change(async () => {
            await this.particles().refresh();
        })
            .addItems([
            {
                value: "bottom",
            },
            {
                value: "bottom-left",
            },
            {
                value: "bottom-right",
            },
            {
                value: "left",
            },
            {
                value: "none",
            },
            {
                value: "right",
            },
            {
                value: "top",
            },
            {
                value: "top-left",
            },
            {
                value: "top-right",
            },
        ]);
        group.addProperty("drift", "Drift", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("enable", "Enable", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("random", "Random", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("size", "Size", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("speed", "Speed", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("straight", "Straight", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("vibrate", "Vibrate", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("warp", "Warp", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
    }
    addTrail() {
        const group = this.group.addGroup("trail", "Trail");
        const optionsFunc = group.data;
        const options = optionsFunc();
        const color = typeof options.fillColor === "string" ? options.fillColor : options.fillColor?.value;
        group.addProperty("enable", "Enable", EditorType.boolean).change(async () => {
            await this.particles().refresh();
        });
        group.addProperty("fillColor", "Fill Color", EditorType.color, color, false).change(async (value) => {
            const options = optionsFunc();
            if (typeof value === "string") {
                if (typeof options.fillColor === "string") {
                    options.fillColor = value;
                }
                else {
                    if (options.fillColor === undefined) {
                        options.fillColor = {
                            value: value,
                        };
                    }
                    else {
                        options.fillColor.value = value;
                    }
                }
            }
            await this.particles().refresh();
        });
        group.addProperty("length", "Length", EditorType.number).change(async () => {
            await this.particles().refresh();
        });
    }
}
